@@ -14,7 +14,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2010 Red Hat, Inc.
+ * (C) Copyright 2010 - 2018 Red Hat, Inc.
  */
 
 #ifndef NMC_DEVICES_H
@@ -32,22 +32,22 @@ void monitor_devices (NmCli *nmc);
 
 NMDevice ** nmc_get_devices_sorted (NMClient *client);
 
-void nmc_device_state_to_color (NMDeviceState state, NmcTermColor *color, NmcTermFormat *color_fmt);
+NMMetaColor nmc_device_state_to_color (NMDeviceState state);
 
-extern NmcOutputField nmc_fields_dev_status[];
-extern NmcOutputField nmc_fields_dev_show_general[];
-extern NmcOutputField nmc_fields_dev_show_connections[];
-extern NmcOutputField nmc_fields_dev_show_cap[];
-extern NmcOutputField nmc_fields_dev_show_wired_prop[];
-extern NmcOutputField nmc_fields_dev_show_wifi_prop[];
-extern NmcOutputField nmc_fields_dev_show_wimax_prop[];
-extern NmcOutputField nmc_fields_dev_wifi_list[];
-extern NmcOutputField nmc_fields_dev_wimax_list[];
-extern NmcOutputField nmc_fields_dev_show_master_prop[];
-extern NmcOutputField nmc_fields_dev_show_team_prop[];
-extern NmcOutputField nmc_fields_dev_show_vlan_prop[];
-extern NmcOutputField nmc_fields_dev_show_bluetooth[];
-extern NmcOutputField nmc_fields_dev_show_sections[];
-extern NmcOutputField nmc_fields_dev_lldp_list[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_status[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_general[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_connections[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_cap[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_wired_prop[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_wifi_prop[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_wimax_prop[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_wifi_list[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_wimax_list[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_master_prop[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_team_prop[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_vlan_prop[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_bluetooth[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_show_sections[];
+extern const NmcMetaGenericInfo *const nmc_fields_dev_lldp_list[];
 
 #endif /* NMC_DEVICES_H */
