@@ -27,8 +27,6 @@
 
 #include "nm-default.h"
 
-#include "NetworkManager.h"
-
 #include "nm-editor-utils.h"
 #if 0
 #include "nm-vpn-helpers.h"
@@ -323,7 +321,7 @@ get_available_iface_name (const char *try_name,
 	const GPtrArray *connections;
 	NMConnection *connection;
 	char *new_name;
-	unsigned int num = 1;
+	unsigned num = 1;
 	int i = 0;
 	const char *ifname = NULL;
 
