@@ -1308,11 +1308,11 @@ get_type_name (NMDevice *device)
 	case NM_DEVICE_TYPE_OLPC_MESH:
 		return _("OLPC Mesh");
 	case NM_DEVICE_TYPE_OVS_INTERFACE:
-		return _("Open vSwitch Interface");
+		return _("OpenVSwitch Interface");
 	case NM_DEVICE_TYPE_OVS_PORT:
-		return _("Open vSwitch Port");
+		return _("OpenVSwitch Port");
 	case NM_DEVICE_TYPE_OVS_BRIDGE:
-		return _("Open vSwitch Bridge");
+		return _("OpenVSwitch Bridge");
 	case NM_DEVICE_TYPE_WIMAX:
 		return _("WiMAX");
 	case NM_DEVICE_TYPE_MODEM:
@@ -1907,11 +1907,10 @@ nm_device_is_software (NMDevice *device)
 /**
  * nm_device_reapply:
  * @device: a #NMDevice
- * @connection: (allow-none): the #NMConnection to replace the applied
- *   settings with or %NULL to reuse existing
- * @version_id: zero or the expected version id of the applied connection.
- *   If specified and the version id mismatches, the call fails without
- *   modification. This allows to catch concurrent accesses.
+ * @connection: the #NMConnection to replace the applied settings with or %NULL to reuse existing
+ * @version_id: zero or the expected version id of the applied connection. If specified
+ *   and the version id mismatches, the call fails without modification. This allows to
+ *   catch concurrent accesses.
  * @flags: always set this to zero
  * @cancellable: a #GCancellable, or %NULL
  * @error: location for a #GError, or %NULL
@@ -1970,12 +1969,10 @@ device_reapply_cb (GObject *proxy,
 /**
  * nm_device_reapply_async:
  * @device: a #NMDevice
- * @connection: (allow-none): the #NMConnection to replace the applied
- *   settings with or %NULL to reuse existing
- * @version_id: zero or the expected version id of the applied
- *   connection. If specified and the version id mismatches, the call
- *   fails without modification. This allows to catch concurrent
- *   accesses.
+ * @connection: the #NMConnection to replace the applied settings with or %NULL to reuse existing
+ * @version_id: zero or the expected version id of the applied connection. If specified
+ *   and the version id mismatches, the call fails without modification. This allows to
+ *   catch concurrent accesses.
  * @flags: always set this to zero
  * @cancellable: a #GCancellable, or %NULL
  * @callback: callback to be called when the reapply operation completes
@@ -2524,7 +2521,7 @@ nm_device_connection_compatible (NMDevice *device, NMConnection *connection, GEr
  * incompatible with the device. To get the full list of connections see
  * nm_client_get_connections().
  *
- * Returns: (transfer full) (element-type NMConnection): an array of
+ * Returns: (transfer container) (element-type NMConnection): an array of
  * #NMConnections that could be activated with the given @device.  The array
  * should be freed with g_ptr_array_unref() when it is no longer required.
  **/
