@@ -120,11 +120,7 @@ gboolean nm_device_ipv6_sysctl_set (NMDevice *self, const char *property, const
 gint64 nm_device_get_configured_mtu_from_connection_default (NMDevice *self,
                                                              const char *property_name);
 
-guint32 nm_device_get_configured_mtu_from_connection (NMDevice *device,
-                                                      GType setting_type,
-                                                      NMDeviceMtuSource *out_source);
-
-guint32 nm_device_get_configured_mtu_for_wired (NMDevice *self, NMDeviceMtuSource *out_source);
+guint32 nm_device_get_configured_mtu_for_wired (NMDevice *self, gboolean *out_is_user_config);
 
 void nm_device_commit_mtu (NMDevice *self);
 
