@@ -24,22 +24,28 @@
 #include "nm-ip4-config.h"
 #include "nm-ip6-config.h"
 
+typedef enum {
+	NM_DHCP_DUID_ENFORCE_NEVER = 0,
+	NM_DHCP_DUID_ENFORCE_LEASE_FALLBACK,
+	NM_DHCP_DUID_ENFORCE_ALWAYS,
+} NMDhcpDuidEnforce;
+
 NMIP4Config *nm_dhcp_utils_ip4_config_from_options (struct _NMDedupMultiIndex *multi_idx,
                                                     int ifindex,
                                                     const char *iface,
                                                     GHashTable *options,
-                                                    guint priority);
+                                                    guint32 route_table,
+                                                    guint32 route_metric);
 
 NMIP6Config *nm_dhcp_utils_ip6_config_from_options (struct _NMDedupMultiIndex *multi_idx,
                                                     int ifindex,
                                                     const char *iface,
                                                     GHashTable *options,
-                                                    guint priority,
                                                     gboolean info_only);
 
 NMPlatformIP6Address nm_dhcp_utils_ip6_prefix_from_options (GHashTable *options);
 
-char *       nm_dhcp_utils_duid_to_string          (const GByteArray *duid);
+char *nm_dhcp_utils_duid_to_string (GBytes *duid);
 
 GBytes *     nm_dhcp_utils_client_id_string_to_bytes (const char *client_id);
 
